@@ -35,14 +35,16 @@ class DanglingIndicesClient(NamespacedClient):
             t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
         ] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[t.Union[int, str]] = None,
+        master_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union[int, str]] = None,
+        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Deletes the specified dangling index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/modules-gateway-dangling-indices.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/modules-gateway-dangling-indices.html>`_
 
         :param index_uuid: The UUID of the dangling index
         :param accept_data_loss: Must be set to true in order to delete the dangling
@@ -86,14 +88,16 @@ class DanglingIndicesClient(NamespacedClient):
             t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
         ] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[t.Union[int, str]] = None,
+        master_timeout: t.Optional[
+            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+        ] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union[int, str]] = None,
+        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Imports the specified dangling index
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/modules-gateway-dangling-indices.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/modules-gateway-dangling-indices.html>`_
 
         :param index_uuid: The UUID of the dangling index
         :param accept_data_loss: Must be set to true in order to import the dangling
@@ -140,7 +144,7 @@ class DanglingIndicesClient(NamespacedClient):
         """
         Returns all dangling indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.3/modules-gateway-dangling-indices.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/modules-gateway-dangling-indices.html>`_
         """
         __path = "/_dangling"
         __query: t.Dict[str, t.Any] = {}
